### Participation of Users in Chat
_Following Bar chart depicts how two participants in a Private Chat contributed to that Chat_

![participationInPrivateChatByUser](../plots/participationInPrivateChatByUser.png)

_This one depicts how participants in a Group Chat contributed to that Chat_

![participationInGroupChatByUser](../plots/participationInGroupChatByUser.png)

_For sake of **Privacy** Participants' Contact Names/ Numbers are partially grayed_
